============
Installation
============

At the command line::

    $ easy_install requests-forecast

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv requests-forecast
    $ pip install requests-forecast